@@ -30,9 +30,10 @@
 /**
  * dmc_is_luks - check if @path points to a LUKS volume (cf. normal dm-crypt)
  * @path:	path to the crypto container
+ * @header:	path to the LUKS header file or block device (can match @path)
  * @blkdev:	path is definitely a block device
  */
-EXPORT_SYMBOL int ehd_is_luks(const char *path, bool blkdev)
+EXPORT_SYMBOL int ehd_is_luks(const char *path, const char *header, bool blkdev)
 {
 	struct crypt_device *cd;
 	const char *device = path;
@@ -52,7 +53,11 @@ EXPORT_SYMBOL int ehd_is_luks(const char *path, bool blkdev)
 		device = loop_device;
 	}
 
-	ret = crypt_init(&cd, device);
+	if (header != NULL)
+		ret = crypt_init_data_device(&cd, header, device);
+	else
+		ret = crypt_init(&cd, device);
+
 	if (ret == 0) {
 		ret = crypt_load(cd, CRYPT_LUKS, NULL);
 		if (ret == -EINVAL)
@@ -96,7 +101,11 @@ static bool dmc_run(const struct ehd_mount_request *req,
 	char *cipher = NULL, *mode;
 	int ret;
 
-	ret = crypt_init(&cd, mt->lower_device);
+	if (mt->header != NULL)
+		ret = crypt_init_data_device(&cd, mt->header, mt->lower_device);
+	else
+		ret = crypt_init(&cd, mt->lower_device);
+
 	if (ret < 0) {
 		fprintf(stderr, "crypt_init: %s\n", strerror(-ret));
 		return false;
@@ -112,6 +121,24 @@ static bool dmc_run(const struct ehd_mount_request *req,
 #endif
 	}
 
+	if (req->no_read_workqueue) {
+#ifdef CRYPT_ACTIVATE_NO_READ_WORKQUEUE
+		flags |= CRYPT_ACTIVATE_NO_READ_WORKQUEUE;
+#else
+		fprintf(stderr, "CRYPT_ACTIVATE_NO_READ_WORKQUEUE requested, "
+		        "but not provided by your libcryptsetup.\n");
+#endif
+	}
+
+	if (req->no_write_workqueue) {
+#ifdef CRYPT_ACTIVATE_NO_WRITE_WORKQUEUE
+		flags |= CRYPT_ACTIVATE_NO_WRITE_WORKQUEUE;
+#else
+		fprintf(stderr, "CRYPT_ACTIVATE_NO_WRITE_WORKQUEUE requested, "
+		        "but not provided by your libcryptsetup.\n");
+#endif
+	}
+
 	ret = crypt_load(cd, CRYPT_LUKS, NULL);
 	if (ret == 0) {
 		ret = crypt_activate_by_passphrase(cd, mt->crypto_name,
