@@ -115,7 +115,8 @@ static void run_ofl(const struct config *const config, const char *mntpt,
 }
 
 /**
- * Compares a given utab entry to the volume. crypt-type volumes will always
+ * Compares a given utab entry to the combopath (vpt->combopath == 
+ * vpt->volume for non-network volumes). crypt-type volumes will always
  * be compared case-sensitive since they always use an existing file.
  */
 static bool pmt_utabent_matches(const struct vol *vpt, struct libmnt_fs *fs)
@@ -126,10 +127,19 @@ static bool pmt_utabent_matches(const struct vol *vpt, struct libmnt_fs *fs)
 	bool result = false;
 
 	xcmp = fstype2_icase(vpt->type) ? strcasecmp : strcmp;
-	if (source != NULL)
-		result = xcmp(vpt->volume, source) == 0;
+	if (source != NULL) {
+		if (strcmp(vpt->fstype, "fuse") != 0)
+			result = xcmp(vpt->combopath, source) == 0;
+		else {
+			size_t len_combopath = strlen(vpt->combopath);
+			size_t len_source = strlen(source);
+			result = xcmp(vpt->combopath + len_combopath - len_source, source) == 0;
+		}
+	}
+
 	if (target != NULL)
 		result &= strcmp(vpt->mountpoint, target) == 0;
+
 	return result;
 }
 
@@ -252,13 +262,13 @@ static void log_pm_input(const struct config *const config,
 		"Mount info: %s, user=%s <volume fstype=\"%s\" "
 		"server=\"%s\" path=\"%s\" "
 		"mountpoint=\"%s\" cipher=\"%s\" fskeypath=\"%s\" "
-		"fskeycipher=\"%s\" fskeyhash=\"%s\" options=\"%s\" /> "
+		"fskeycipher=\"%s\" fskeyhash=\"%s\" header=\"%s\" options=\"%s\" /> "
 		"fstab=%u ssh=%u\n",
 		vpt->globalconf ? "globalconf" : "luserconf",
 		znul(vpt->user), znul(vpt->fstype),
 		znul(vpt->server), znul(vpt->volume),
 		vpt->mountpoint, znul(vpt->cipher), znul(vpt->fs_key_path),
-		znul(vpt->fs_key_cipher), znul(vpt->fs_key_hash), options,
+		znul(vpt->fs_key_cipher), znul(vpt->fs_key_hash), znul(vpt->header), options,
 		vpt->use_fstab, vpt->uses_ssh
 	);
 	HXmc_free(options);
@@ -795,6 +805,7 @@ int mount_op(mount_op_fn_t *mnt, const struct config *config,
 	format_add(vinfo, "FSKEYCIPHER", vpt->fs_key_cipher);
 	format_add(vinfo, "FSKEYHASH",   vpt->fs_key_hash);
 	format_add(vinfo, "FSKEYPATH",   vpt->fs_key_path);
+	format_add(vinfo, "HEADER",      vpt->header);
 	misc_add_ntdom(vinfo, vpt->user);
 
 	if ((pe = getpwnam(vpt->user)) == NULL) {
