@@ -79,7 +79,7 @@ struct vol {
 	/* was handed off to mount_op() */
 	bool mnt_processed;
 	const char *user;
-	char *fstype, *server, *volume, *combopath, *mountpoint, *cipher;
+	char *fstype, *server, *volume, *combopath, *mountpoint, *header, *cipher;
 	char *fs_key_cipher, *fs_key_hash, *fs_key_path;
 	/* May be NULL if no options */
 	struct HXclist_head options;
@@ -178,6 +178,7 @@ enum cmtab_field {
 	CMTABF_CONTAINER,
 	CMTABF_LOOP_DEV,
 	CMTABF_CRYPTO_DEV,
+	CMTABF_HEADER,
 	__CMTABF_MAX,
 };
 
