@@ -61,7 +61,7 @@ struct callbackmap {
 
 struct pmt_command {
 	enum command_type type;
-	const char *fs, *def[11];
+	const char *fs, *def[12];
 	/*
 	 * You will need to enlarge @def whenever the compiler
 	 * (rightfully) complains.
@@ -193,6 +193,8 @@ bool expandconfig(struct config *config)
 		    !expand_user(u, &vpt->volume, vinfo) ||
 		    !expand_home(u, &vpt->mountpoint) ||
 		    !expand_user(u, &vpt->mountpoint, vinfo) ||
+		    !expand_home(u, &vpt->header) ||
+		    !expand_user(u, &vpt->header, vinfo) ||
 		    !expand_home(u, &vpt->fs_key_path) ||
 		    !expand_user(u, &vpt->fs_key_path, vinfo) ||
 		    !expand_user(u, &vpt->fs_key_cipher, vinfo))
@@ -224,6 +226,7 @@ static void volume_free(struct vol *vol)
 	free(vol->fstype);
 	free(vol->server);
 	free(vol->volume);
+	free(vol->header);
 	HXmc_free(vol->combopath);
 	free(vol->cipher);
 	free(vol->fs_key_cipher);
@@ -611,14 +614,14 @@ static int pmt_strregmatch(const char *s, const char *pattern, bool icase)
 	ret = pcre2_match(rd, reinterpret_cast(PCRE2_SPTR, s), strlen(s),
 	      0, 0, match_data, 0);
 	if (ret == PCRE2_ERROR_NOMATCH) {
-		l0g("pcre_exec: no match\n");
+		w4rn("pcre_exec: no match\n");
 		ret = false;
 	} else if (ret < 0) {
 		ret = false;
 		l0g("pcre_exec: error code %d\n", ret);
 	} else {
 		ret = true;
-		l0g("pcre_exec: /%s/: %d matches\n", pattern, ret);
+		w4rn("pcre_exec: /%s/: %d matches\n", pattern, ret);
 	}
 	pcre2_match_data_free(match_data);
 	pcre2_code_free(rd);
@@ -1365,6 +1368,10 @@ static const char *rc_volume(xmlNode *node, struct config *config,
 		free(vpt->volume);
 		vpt->volume = tmp;
 	}
+	if ((tmp = xml_getprop(node, "header")) != NULL) {
+		free(vpt->header);
+		vpt->header = tmp;
+	}
 
 	/* Destination */
 	if ((tmp = xml_getprop(node, "mountpoint")) != NULL) {
@@ -1460,8 +1467,8 @@ static const struct pmt_command default_command[] = {
 	 */
 	{CMD_NFSMOUNT,    "nfs",   {"mount", "%(if %(OPTIONS),-o%(OPTIONS))", "-t%(FSTYPE)", "%(COMBOPATH)", "%(MNTPT)", NULL}},
 	{CMD_NFSMOUNT,    "nfs4"},
-	{CMD_LCLMOUNT,    NULL,    {"mount", "%(if %(OPTIONS),-o%(OPTIONS))", "-t%(FSTYPE)", "%(VOLUME)", "%(MNTPT)", NULL}},
-	{CMD_CRYPTMOUNT,  "crypt", {"mount", "-t", "crypt", "%(if %(CIPHER),-ocipher=%(CIPHER))", "%(if %(FSKEYCIPHER),-ofsk_cipher=%(FSKEYCIPHER))", "%(if %(FSKEYHASH),-ofsk_hash=%(FSKEYHASH))", "%(if %(FSKEYPATH),-okeyfile=%(FSKEYPATH))", "%(if %(OPTIONS),-o%(OPTIONS))", "%(VOLUME)", "%(MNTPT)", NULL}},
+	{CMD_LCLMOUNT,    NULL,    {"mount", "%(if %(OPTIONS),-o%(OPTIONS))", "-t%(FSTYPE)", "%(if %(HEADER),-oheader=%(HEADER))", "%(VOLUME)", "%(MNTPT)", NULL}},
+	{CMD_CRYPTMOUNT,  "crypt", {"mount", "-t", "crypt", "%(if %(CIPHER),-ocipher=%(CIPHER))", "%(if %(FSKEYCIPHER),-ofsk_cipher=%(FSKEYCIPHER))", "%(if %(FSKEYHASH),-ofsk_hash=%(FSKEYHASH))", "%(if %(FSKEYPATH),-okeyfile=%(FSKEYPATH))", "%(if %(OPTIONS),-o%(OPTIONS))", "%(if %(HEADER),-oheader=%(HEADER))", "%(VOLUME)", "%(MNTPT)", NULL}},
 	{CMD_CRYPTMOUNT,  "crypt_LUKS"},
 	{CMD_CRYPTMOUNT,  "crypto_LUKS"},
 	{CMD_CRYPTUMOUNT, "crypt", {"umount", "%(MNTPT)", NULL}},
